%define	name	krbafs
%define	version	1.2.2
%define	release	4mdk

%define	major	0
%define libname	%mklibname %{name} %{major}

Summary:	A Kerberos to AFS bridging library, built against Kerberos 5.
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	Freely Distributable
Group:		System/Libraries
URL:		ftp://ftp.pdc.kth.se/pub/krb/src/
Source0:	ftp://ftp.pdc.kth.se/pub/krb/src/krb4-%{version}.tar.bz2
Source1:	krbafs.versions
Patch1:		krb4-1.2.2-automake1.7.patch.bz2
BuildPrereq:	krb5-devel
BuildRequires:	automake1.7
Buildroot:	%{_tmppath}/%{name}-root

%define k5prefix %_prefix
%define fake_aklog 0

%description
This package contains the krbafs shared library, which allows programs
to obtain AFS network filesystem tokens using Kerberos IV credentials,
without having to link with official AFS libraries which may not be
available for a given platform.

%package -n	%{libname}
Summary:	A Kerberos to AFS bridging library, built against Kerberos 5.
Group:          System/Libraries
Obsoletes:	%{name}
Provides:	%{name}

%description -n	%{libname}
This package contains the krbafs shared library, which allows programs
to obtain AFS network filesystem tokens using Kerberos IV credentials,
without having to link with official AFS libraries which may not be
available for a given platform.

%package -n	%{libname}-devel
Summary:	Development files for use with the krbafs package.
Group:		System/Libraries
Obsoletes:	%{name}-devel lib%{name}-devel
Provides:	%{name}-devel lib%{name}-devel
Requires:	%{libname} = %{version}-%{release}

%description -n	%{libname}-devel
This package contains header files and static libraries for use when
building applications which use the krbafs library.

%package -n	%{name}-utils
Summary:	Kerberos/AFS utilities.
Group:		System/Libraries

%description -n	%{name}-utils
Kerberos is a network authentication system. The krbafs-utils package
contains versions of afslog, pagsh, and kstring2key that are linked
against libkrbafs (a Kerberos to AFS bridging library).

%prep

%setup -q -n krb4-%{version}
%patch1 -p1 -b .automake1_7

# Do a large amount of renaming to keep from conflicting with versions
# of
# libkafs in the wild.
find . -type f | xargs perl -pi -e 's,kafs,krbafs,g'
find . -type f | xargs perl -pi -e 's,krb_life_to_time,krbafs_life_to_time,g'
find . -type f | xargs perl -pi -e 's,krb_time_to_life,krbafs_time_to_life,g'
find . -type f | xargs perl -pi -e 's,afs_string_to_key,krbafs_string_to_key,g'
find . -type d -name "*kafs*" | xargs rename kafs krbafs
find . -type f -name "*kafs*" | xargs rename kafs krbafs
sed 's,MY.REALM.NAME,EXAMPLE.COM,g' etc/krb.realms > krb.realms
sed 's,MY.REALM.NAME,EXAMPLE.COM,g' etc/krb.conf   > krb.conf
libtoolize -f -c
aclocal-1.7 -I cf
automake-1.7 -a -c
autoheader
autoconf

%build
# First, configure the source tree.
CFLAGS="%{optflags} -fPIC" \
LIBS="-lcrypt" \
%configure --enable-shared \
    --disable-static \
    --without-readline \
    --without-hesiod \
    --without-openssl

# We define this macro to override settings to allow us to use headers and
# libraries from an installed krb5 setup.
%define makesub make INCLUDE_krb4="-I%{_includedir}/kerberosIV" INCLUDE_des="-I%{_includedir}/kerberosIV -I`pwd`/lib/krbafs" LIB_krb4="-lcrypt -lkrb4" LIB_des="-ldes425 -lk5crypto" LIB_roken=

# Generate needed header files and libraries.
%makesub -C include protos.h
%makesub -C lib/roken roken.h
%makesub -C lib/krb krb.h

for subdir in lib/krbafs appl/afsutil ; do
	# Copy over headers which will need to be used by additional modules.
	cp -f lib/krb/krb_locl.h ${subdir}
	cp -f lib/krb/krb_log.h ${subdir}
	cp -f lib/krb/krb-protos.h ${subdir}
	cp -f lib/krb/prot.h ${subdir}
	cp -f include/protos.h ${subdir}

	# Copy some of the modules from libkrb to the library.
	krbc="get_default_principal lifetime str2key"
	krbo="get_default_principal.o lifetime.o str2key.o"
	krblo="get_default_principal.lo lifetime.lo str2key.lo"
	for krb in $krbc ; do
		cp -f lib/krb/${krb}.c ${subdir}
		%makesub -C ${subdir} ${krb}.lo
	done

	# Copy some of the modules from libroken to the library.
	rokenc="esetenv getprogname k_getpwuid setprogname strlwr"
	rokeno="esetenv.o getprogname.o k_getpwuid.o setprogname.o strlwr.o"
	rokenlo="esetenv.lo getprogname.lo k_getpwuid.lo setprogname.lo strlwr.lo"
	for roken in $rokenc ; do
		cp -f lib/roken/${roken}.c ${subdir}
		%makesub -C ${subdir} ${roken}.lo
	done
done

# Build the shared library, adding in the modules needed to keep the library
# from having undesirable undefined symbols.
%makesub -C lib/krbafs libkrbafs.la \
	libkrbafs_la_DEPENDENCIES= \
	libkrbafs_la_LIBADD="${krblo} ${rokenlo}" \
	libkrbafs_la_LDFLAGS="-Wl,-version-script=%{SOURCE1}"

# Build the bundled apps.
cp -f lib/roken/strlcpy.c appl/afsutil
%makesub -C appl/afsutil strlcpy.lo
%makesub -C appl/afsutil \
	LDADD="../../lib/krbafs/libkrbafs.la ${krblo} ${rokenlo} strlcpy.lo "'$(LIB_krb4)'

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%makesub -C lib/krbafs install DESTDIR=%{buildroot} libkrbafs_la_DEPENDENCIES=
%makesub -C appl/afsutil install DESTDIR=%{buildroot}
test -d %{buildroot}%{_sysconfdir} || mkdir -p %{buildroot}%{_sysconfdir}
install -m644 krb.conf krb.realms %{buildroot}%{_sysconfdir}

%if %{fake_aklog}
%ifnarch i386
# CMU's aklog can't be built against Arla... not yet, anyway.
(mkdir -p %{buildroot}/usr/athena/etc; \
 ln -s ../../kerberos/bin/afslog %{buildroot}/usr/athena/etc/aklog)
%endif
%endif

rm -rf %{buildroot}/%{_libdir}/*.la \
    %{buildroot}%{_mandir}/cat*

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%files -n %{libname}
%defattr(-,root,root)
%doc COPYRIGHT lib/krbafs/ChangeLog
%config(noreplace) %{_sysconfdir}/*
%{_libdir}/*.so.*

%files -n %{libname}-devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_mandir}/man3/*.3*

%files utils
%defattr(-,root,root)
%{_bindir}/*
%{_mandir}/man1/*.1*

%if %{fake_aklog}
%ifnarch %{ix86}
/usr/athena/etc/*
%endif
%endif

%changelog
* Wed Mar 16 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.2.2-4mdk
- run automake
- patch1: fix build with automake 1.7.x

* Thu Nov 18 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.2.2-3mdk
- buildrequires

* Sun Aug 08 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.2.2-2mdk
- libifiction
- misc spec file fixes

* Wed Sep 03 2003 Florin <florin@mandrakesoft.com> 1.2.2-1mdk
- 1.2.2
- remove the already integrated dnparser patch

* Wed Jan 22 2003 Florin <florin@mandrakesoft.com> 1.1.1-2mdk
- small fixes

* Tue Jan 21 2003 Florin <florin@mandrakesoft.com> 1.1.1-1mdk
- mandrake adaptions

* Tue Dec 03 2002 Elliot Lee <sopwith@redhat.com> 1.1.1-8
- Remove unpackaged files

* Tue Oct  9 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1.1-7
- backport dns resolver from 1.2 to properly handle truncated responses
- fixup paths for multilib systems

* Mon Aug 12 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1.1-6
- reference files in the source tree properly at build-time

* Wed Jul 17 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1.1-5
- own the man page directory

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 16 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1.1-2
- rebuild in new environment

* Fri Mar  1 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1.1-1
- update to 1.1.1
- build shared only, and use a map file to only export symbols from the
  shared library which are declared in the header

* Fri Feb 22 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1-4
- rebuild

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Nov 13 2001 Nalin Dahyabhai <nalin@redhat.com> 1.1-2
- remove explicit dependency on krb5-libs

* Thu Oct 18 2001 Nalin Dahyabhai <nalin@redhat.com> 1.1-1
- update to 1.1

* Thu Aug 16 2001 Nalin Dahyabhai <nalin@redhat.com>
- obey RPM_OPT_FLAGS

* Tue Jul 24 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.9

* Wed Jul 11 2001 Nalin Dahyabhai <nalin@redhat.com>
- break out the -devel subpackage
- make the subpackages require the main package

* Thu Jul  5 2001 Nalin Dahyabhai <nalin@redhat.com>
- include sample krb.conf and krb.realms files from the source package
  in the binary package, tweaked for the EXAMPLE.COM realm
- add doc files

* Tue Apr 24 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.8

* Thu Dec 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.5

* Mon Dec 11 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.4

* Mon Oct 23 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.3

* Mon Oct  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- drop dangling symlink (#18750)

* Wed Aug 16 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix summary and description

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Thu Jun 29 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.2

* Tue Jun 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new build environment (release 3)

* Sun Jun  4 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix for compiling with new gcc

* Tue Mar 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.0.1

* Tue Mar  7 2000 Jeff Johnson <jbj@redhat.com>
- rebuild for sparc baud rates > 38400.

* Thu Mar 02 2000 Nalin Dahyabhai <nalin@redhat.com>
- add Requires: krb5-libs and BuildPrereq: krb5-devel

* Thu Jan 06 2000 Nalin Dahyabhai <nalin@redhat.com>
- make prefix changeable in case we decide to move it later

* Wed Dec 16 1999 Nalin Dahyabhai <nsdahya1@pobox.com>
- update to 1.0 (whee!)

* Mon Dec 13 1999 Nalin Dahyabhai <nsdahya1@pobox.com>
- link shared lib against libresolv and libcrypt to help resolve symbols in
  configure tests
- make %ifarch ppc parts %ifnarch i386

* Thu Dec 02 1999 Jeremy Katz <jlkatz@unity.ncsu.edu>
- Build the static lib for libkrbafs as well as linking against all the necessary libs
  with the shared lib
* Wed Dec 01 1999 Jeremy Katz <jlkatz@unity.ncsu.edu>
- Added ppc-specific symlinking afslog as replacement for aklog

* Tue Nov 30 1999 Nalin Dahyabhai <nalin.dahyabhai@pobox.com>
- initial version
